@@ -52,7 +52,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.3.15"
+__version__ = "3.3.21"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_SD.git"
 
 _CMD_TIMEOUT = const(200)
@@ -68,6 +68,7 @@ _TOKEN_CMD25 = const(0xFC)
 _TOKEN_STOP_TRAN = const(0xFD)
 _TOKEN_DATA = const(0xFE)
 
+
 # pylint: disable-msg=superfluous-parens
 class SDCard:
     """Controls an SD card over SPI.
@@ -94,6 +95,7 @@ class SDCard:
 
     """
 
+    # pylint: disable=invalid-name
     def __init__(self, spi: SPI, cs: DigitalInOut, baudrate: int = 1320000) -> None:
         # Create an SPIDevice running at a lower initialization baudrate first.
         self._spi = spi_device.SPIDevice(spi, cs, baudrate=250000, extra_clocks=8)
@@ -499,6 +501,7 @@ class SDCard:
                     )
                     offset += 512
                     nblocks -= 1
+                self._wait_for_ready(card)
                 self._cmd_nodata(card, _TOKEN_STOP_TRAN, 0x0)
         return 0
 
